import { Github, Mail, Phone, MapPin, ChevronDown, ExternalLink, Shield, Book, Globe, Brain } from 'lucide-react';

export const App = () => {
  return (
    <div className='min-h-screen bg-gray-50'>
      {/* Hero Section */}
      <header className='bg-gradient-to-r from-blue-600 to-indigo-700 text-white'>
        <nav className='container mx-auto px-6 py-4 flex justify-between items-center'>
          <div className='flex items-center space-x-4'>
            <img src='https://kevisual.cn/root/center/panda.jpg' alt='Kevisual Logo' className='h-10 w-10 object-contain' />
            <span className='text-xl font-bold'>Kevisual 助手</span>
          </div>
          <div className='hidden md:flex space-x-6'>
            <a href='#features' className='hover:text-gray-200'>
              功能
            </a>
            <a href='#about' className='hover:text-gray-200'>
              关于我们
            </a>
            <a href='#contact' className='hover:text-gray-200'>
              联系方式
            </a>
          </div>
        </nav>

        <div className='container mx-auto px-6 py-24 text-center'>
          <h1 className='text-4xl md:text-6xl font-bold mb-6'>加速你的工作，生活，学习</h1>
          <p className='text-xl md:text-2xl mb-8 opacity-90'>专业的网页助手，让您的在线体验更轻松、更高效</p>
          <ChevronDown className='w-8 h-8 mx-auto animate-bounce' />
        </div>
      </header>

      {/* Features Section */}
      <section id='features' className='py-20 bg-white'>
        <div className='container mx-auto px-6'>
          <h2 className='text-3xl font-bold text-center mb-16'>核心功能</h2>

          <div className='grid md:grid-cols-3 gap-12'>
            <div className='p-6 rounded-lg shadow-lg bg-white'>
              <Globe className='w-12 h-12 text-blue-600 mb-4' />
              <h3 className='text-xl font-semibold mb-4'>网页部署平台</h3>
              <p className='text-gray-600'>轻松管理您的博客和自定义网页，支持文件管理、站点创建和域名自定义</p>
            </div>

            <div className='p-6 rounded-lg shadow-lg bg-white'>
              <Brain className='w-12 h-12 text-blue-600 mb-4' />
              <h3 className='text-xl font-semibold mb-4'>AI Mark 推荐</h3>
              <p className='text-gray-600'>智能工具库助您快速找到解决方案，汇集优质开源项目</p>
            </div>

            <div className='p-6 rounded-lg shadow-lg bg-white'>
              <Book className='w-12 h-12 text-blue-600 mb-4' />
              <h3 className='text-xl font-semibold mb-4'>笔记助手</h3>
              <p className='text-gray-600'>AI驱动的笔记工具，帮助您创造性地生成美观的内容并进行可视化</p>
            </div>
          </div>
        </div>
      </section>

      {/* About Section */}
      <section id='about' className='py-20 bg-gray-50'>
        <div className='container mx-auto px-6'>
          <h2 className='text-3xl font-bold text-center mb-16'>关于我们</h2>
          <div className='max-w-3xl mx-auto text-center'>
            <p className='text-gray-600 mb-8'>我们是一个独立开发团队，致力于提供高质量的软件产品。我们的使命是通过创新技术，让用户的工作和生活更加便捷。</p>
            <div className='grid md:grid-cols-2 gap-8'>
              <div>
                <h3 className='text-xl font-semibold mb-4'>我们的使命</h3>
                <ul className='text-left text-gray-600 space-y-2'>
                  <li>✓ 提供高质量的软件产品</li>
                  <li>✓ 不断创新，满足用户需求</li>
                  <li>✓ 提供优质的售后服务</li>
                  <li>✓ 保护用户隐私</li>
                </ul>
              </div>
              <div>
                <h3 className='text-xl font-semibold mb-4'>我们的愿景</h3>
                <ul className='text-left text-gray-600 space-y-2'>
                  <li>✓ 创立更简单，方便的网页助手</li>
                  <li>✓ 成为用户信赖的软件品牌</li>
                  <li>✓ 持续创新发展</li>
                  <li>✓ 提供卓越的用户体验</li>
                </ul>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Contact Section */}
      <section id='contact' className='py-20 bg-white'>
        <div className='container mx-auto px-6'>
          <h2 className='text-3xl font-bold text-center mb-16'>联系我们</h2>
          <div className='max-w-2xl mx-auto'>
            <div className='space-y-6'>
              <div className='flex items-center space-x-4'>
                <Mail className='w-6 h-6 text-blue-600' />
                <span>envision@kevisual.cn</span>
              </div>
              <div className='flex items-center space-x-4'>
                <Phone className='w-6 h-6 text-blue-600' />
                <span>18324451015</span>
              </div>
              <div className='flex items-center space-x-4'>
                <MapPin className='w-6 h-6 text-blue-600' />
                <span>浙江省杭州市余杭区闲林街道天日山西路230号A区3楼2954室</span>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className='bg-gray-900 text-white py-12'>
        <div className='container mx-auto px-6'>
          <div className='grid md:grid-cols-4 gap-8'>
            <div>
              <h3 className='text-lg font-semibold mb-4'>Kevisual 助手</h3>
              <p className='text-gray-400'>加速你的工作，生活，学习</p>
            </div>
            <div>
              <h3 className='text-lg font-semibold mb-4'>快速链接</h3>
              <ul className='space-y-2 text-gray-400'>
                <li>
                  <a href='#features' className='hover:text-white'>
                    功能
                  </a>
                </li>
                <li>
                  <a href='#about' className='hover:text-white'>
                    关于我们
                  </a>
                </li>
                <li>
                  <a href='#contact' className='hover:text-white'>
                    联系方式
                  </a>
                </li>
              </ul>
            </div>
            <div>
              <h3 className='text-lg font-semibold mb-4'>法律信息</h3>
              <ul className='space-y-2 text-gray-400'>
                <li>
                  <a href='/privacy' className='hover:text-white'>
                    隐私政策
                  </a>
                </li>
                <li>
                  <a href='/terms' className='hover:text-white'>
                    用户协议
                  </a>
                </li>
              </ul>
            </div>
            <div>
              <h3 className='text-lg font-semibold mb-4'>联系我们</h3>
              <div className='flex space-x-4'>
                <a href='mailto:feedback@kevisual.cn' className='text-gray-400 hover:text-white'>
                  <Mail className='w-6 h-6' />
                </a>
                <a href='https://github.com/' className='text-gray-400 hover:text-white'>
                  <Github className='w-6 h-6' />
                </a>
              </div>
            </div>
          </div>
          <div className='mt-12 pt-8 border-t border-gray-800 text-center text-gray-400'>
            <p>浙ICP备2025158778号</p>
            <p>© 2024 杭州余杭逸文设计工作室. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  );
};

export default App;
